@@ -1,18 +1,13 @@
 package DBIx::Skinny::DBD::mysql;
 use strict;
 use warnings;
-use DBIx::Skinny::SQL;
+use base 'DBIx::Skinny::DBD::Base';
 
 sub last_insert_id {
     $_[1]->{mysql_insertid} || $_[1]->{insertid}
 }
 
-sub sql_for_unixtime {
-    return "UNIX_TIMESTAMP()";
-}
-
-sub quote    { '`' }
-sub name_sep { '.' }
+sub sql_for_unixtime { "UNIX_TIMESTAMP()" }
 
 sub bulk_insert {
     my ($skinny, $table, $args) = @_;
@@ -46,7 +41,5 @@ sub bulk_insert {
     return 1;
 }
 
-sub query_builder_class { 'DBIx::Skinny::SQL' }
-
 1;
 
